// expcond
rename dicegame dicegame_org
rename senstec senstec_org

// assign expcond based on pages delivered to respondent
* dicegame
gen dicegame=.
lab def dicegame ///
    1 "prediction" ///
    2 "roll-a-six"
lab val dicegame dicegame

local i 0
foreach var of varlist Q3_2_3 Q4_2_3 {
    local ++i
    assert missing(dicegame) if `var'<.
    replace dicegame = `i' if `var'<.
}
assert dicegame_org=="predict" if dicegame==1
assert dicegame_org=="roll6" if dicegame==2
tab dicegame*, mis // 17 respondents with breakoffs have not reached the corresponding pages
drop dicegame_org
* senstec
gen senstec=.
lab def senstec ///
    1 "DQ" ///
    2 "CMquest" ///
    3 "UQbenf" ///
    4 "FRnumb"
lab val senstec senstec
local i 0
foreach var of varlist Q8_2_3 Q9_2_3 Q10_2_3 Q11_2_3 {
    local ++i
    assert missing(senstec) if `var'<.
    replace senstec = `i' if `var'<.
}
assert senstec_org=="DQ" if senstec==1
assert senstec_org=="CMunrq" if senstec==2
assert senstec_org=="RRTbenf" if senstec==3
assert senstec_org=="RRTpick" if senstec==4
tab senstec*, mis // 32 respondents with breakoffs have not reached the corresponding pages
drop senstec_org

// design paramaters: pyes, pno, pcm
// - DQ (senstec==1) and missings
forv i = 1/4 {
    qui gen     sq`i'_pyes = cond(senstec==1, 0, -66) if !missing(senstec)
    qui gen     sq`i'_pno = cond(senstec==1, 0, -66) if !missing(senstec)
    qui gen     sq`i'_pcm = cond(senstec==1, 1, -66) if !missing(senstec)
}
// - CM unrelated question (senstec==2)
forv i = 1/4 { // unrelated question
	qui gen sq`i'_uq = ///
		cond(rnd_cmunrq_`i't== ///
			"Is your mother&rsquo;s birthday in January or February?", 1, ///
		cond(rnd_cmunrq_`i't== ///
			"Is your mother&rsquo;s birthday between the 1<sup>st</sup> and the 6<sup>th</sup> of the month (including the 1<sup>st</sup> and 6<sup>th</sup>)?", 2, /// 
		cond(rnd_cmunrq_`i't== ///
			"Is your father&rsquo;s birthday in January or February?", 3, ///
		cond(rnd_cmunrq_`i't== ///
			"Is your father&rsquo;s birthday between the 1<sup>st</sup> and the 6<sup>th</sup> of the month (including the 1<sup>st</sup> and 6<sup>th</sup>)?", 4, /// 
	.)))) if senstec==2	
	lab def sq`i'_uq ///
		1 "mother: birthday Jan-Feb (CM Question)" ///
		2 "mother: birthday 1th-6th (CM Question)" ///
		3 "father: birthday Jan-Feb (CM Question)" ///
		4 "father: birthday 1th-6th (CM Question)"
	lab val sq`i'_uq sq`i'_uq
}
forv i = 1/4 {
    qui replace sq`i'_pyes = 0 if senstec==2
    qui replace sq`i'_pno  = 0 if senstec==2
    qui replace sq`i'_pcm  = ///
        cond(sq`i'_uq==1, 58.2425/365.2425,   /// mother: birthday Jan-Feb
		cond(sq`i'_uq==2, 72/365.2425,   		/// mother: birthday 1th-6th
		cond(sq`i'_uq==3, 58.2425/365.2425,   /// father: birthday Jan-Feb
		cond(sq`i'_uq==4, 72/365.2425,   		/// father: birthday 1th-6th
    .)))) if senstec==2
}
// - UQ Benford (senstec==3)
forv i = 1/4 { // unrelated question
	replace sq`i'_uq = ///
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday between January and June (including January and June)?", 5, ///
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday in an even-numbered month? (i.e. Feb., Apr., Jun., Aug., Oct., or Dec.)", 6, /// 
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday in the first half of the month? (i.e. from the 1<sup>st</sup> to 15<sup>th</sup>)", 7, ///
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday on an even-numbered day? (2<sup>nd</sup>, 4<sup>th</sup>, 6<sup>th</sup>, etc. of the month)", 8, /// 
	.)))) if senstec==3	
	lab def sq`i'_uq ///
		5 "mother: birthday Jan-Jun (UQ Benford)" ///
		6 "mother: even birthmonth (UQ Benford)" ///
		7 "mother: birthday 1st-15th (UQ Benford)" ///
		8 "mother: even birthday (UQ Benford)", add
}
//                            probability of unrelated question
local puq .2218487496   //  1-sum(mm_benford(1::5))
forv i = 1/4 {
    qui replace sq`i'_pyes = /// input p(uq=yes)
        cond(sq`i'_uq==5, 181.2425/365.2425,  /// mother: birthday Jan-Jun
        cond(sq`i'_uq==6, 181.2425/365.2425,  /// mother: even birthmonth
        cond(sq`i'_uq==7, 180/365.2425, 	   /// mother: birthday 1st-15th
        cond(sq`i'_uq==8, 179/365.2425, 	   /// mother: even birthday
        .)))) if senstec==3
    qui replace sq`i'_pno  = 1-sq`i'_pyes if senstec==3 // input p(uq=no) 
    qui replace sq`i'_pyes = sq`i'_pyes*`puq' if senstec==3 // replace with p(uq=yes & uq)
    qui replace sq`i'_pno  = sq`i'_pno*`puq' if senstec==3 // replace with p(uq=no & uq)
    qui replace sq`i'_pcm  = 1 if senstec==3
}
// - FRnumb (senstec==4)
forv i = 1/2 {
    qui replace sq`i'_pyes = 2/12 if senstec==4
    qui replace sq`i'_pno  = 1/12 if senstec==4
    qui replace sq`i'_pcm  = 1 if senstec==4
}
forv i = 3/4 {
    qui replace sq`i'_pyes = 1/12 if senstec==4
    qui replace sq`i'_pno  = 2/12 if senstec==4
    qui replace sq`i'_pcm  = 1 if senstec==4
}
// randomizing device test
gen rndtest=cond(Q13_2_3<.,1, ///
			cond(Q14_5_3<.,2, ///
			cond(Q15_5_3<.,3, ///
			cond(Q16_3_3<.,4, ///
			cond(Q17_3_3<.,5,.)))))
lab def rndtest ///
    1 "Benford procedure" ///
    2 "unrelated questions for CM Question" ///
    3 "unrelated questions for UQ Benford" ///
    4 "pick-a-number device (standard)" ///
    5 "pick-a-number device (generic)"
lab val rndtest rndtest
// -Unrelated question used in CM (rndtest==2)
forv i = 1/4 { // unrelated question
	qui gen rndCM`i'_uq = ///
		cond(rnd_cmunrq_`i't== ///
			"Is your mother&rsquo;s birthday in January or February?", 1, ///
		cond(rnd_cmunrq_`i't== ///
			"Is your mother&rsquo;s birthday between the 1<sup>st</sup> and the 6<sup>th</sup> of the month (including the 1<sup>st</sup> and 6<sup>th</sup>)?", 2, /// 
		cond(rnd_cmunrq_`i't== ///
			"Is your father&rsquo;s birthday in January or February?", 3, ///
		cond(rnd_cmunrq_`i't== ///
			"Is your father&rsquo;s birthday between the 1<sup>st</sup> and the 6<sup>th</sup> of the month (including the 1<sup>st</sup> and 6<sup>th</sup>)?", 4, /// 
	.)))) if rndtest==2	
	lab def rndCM`i'_uq ///
		1 "mother: birthday Jan-Feb (CM Question)" ///
		2 "mother: birthday 1st-6th (CM Question)" ///
		3 "father: birthday Jan-Feb (CM Question)" ///
		4 "father: birthday 1st-6th (CM Question)"
	lab val rndCM`i'_uq rndCM`i'_uq
}
forv i = 1/4 {
    qui gen rndCM`i'_pyes  = ///
        cond(rndCM`i'_uq==1, 58.2425/365.2425,   /// mother: birthday Jan-Feb
		cond(rndCM`i'_uq==2, 72/365.2425,   	/// mother: birthday 1st-6th
		cond(rndCM`i'_uq==3, 58.2425/365.2425,   /// father: birthday Jan-Feb
		cond(rndCM`i'_uq==4, 72/365.2425,   	/// father: birthday 1st-6th
    .)))) if rndtest==2
}
// -Unrelated question used in UQ Benford (rndtest==3)
forv i = 1/4 { // unrelated question
	gen rndbenf`i'_uq = ///
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday between January and June (including January and June)?", 1, ///
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday in an even-numbered month? (i.e. Feb., Apr., Jun., Aug., Oct., or Dec.)", 2, /// 
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday in the first half of the month? (i.e. from the 1<sup>st</sup> to 15<sup>th</sup>)", 3, ///
		cond(rnd_benfunrq_`i't== ///
			"Is your mother&rsquo;s birthday on an even-numbered day? (2<sup>nd</sup>, 4<sup>th</sup>, 6<sup>th</sup>, etc. of the month)", 4, /// 
	.)))) if rndtest==3	
	lab def rndbenf`i'_uq ///
		1 "mother: birthday Jan-Jun (UQ Benford)" ///
		2 "mother: even birthmonth (UQ Benford)" ///
		3 "mother: birthday 1st-15th (UQ Benford)" ///
		4 "mother: even birthday (UQ Benford)"
	lab val rndbenf`i'_uq rndbenf`i'_uq
}
forv i = 1/4 {
    qui gen rndbenf`i'_pyes = ///
        cond(rndbenf`i'_uq==1, 181.2425/365.2425,  /// mother: birthday Jan-Jun
        cond(rndbenf`i'_uq==2, 181.2425/365.2425,  /// mother: even birthmonth
        cond(rndbenf`i'_uq==3, 180/365.2425, 	   /// mother: birthday 1st-15th
        cond(rndbenf`i'_uq==4, 179/365.2425, 	   /// mother: even birthday
        .)))) if rndtest==3
}
drop rnd_cmunrq_*
drop rnd_benfunrq_*
order dicegame senstec rndtest sq?_*  rndCM* rndbenf*, after(loclong)

// collapse pages from experimental conditions and remove filter pages
local page1  "Starting page"
local page2  "Screening question"
local page3  "Personal background I"
local page4  "Intro dice game"
local page5  "Prediction dice game"
local page6  "Dice rolling"
local page7  "Satisfaction"
local page8  "Big Five"
local page9  "Personal background II"
local page10 "MTurk and employment"
local page11 "Intro sensitive questions"
local page12 "Explanation special technique"
local page13 "Benford procedure"
local page14 "Shoplifting"
local page15 "Tax evasion"
local page16 "Voting"
local page17 "Dice game reporting"
local page18 "Trust in survey confidentiality"
local page19 "Evaluation of special technique"
local page20 "Randomizing device test"
local page21 "Birth date knowledge"
local page22 "Respondents' comments"
local page23 "Final page"

*cap drop firstcl* lastc* submit* clcount*
local grps (1_3=1) (1_5=2) (1_9=3) (3_2 4_2=4) (3_4=5) (3_7 4_5=6) (5_3=7) ///
	(5_5=8) (6_4=9) (6_8=10) (6_10=11) /// 
	(9_2 10_2 11_2=12) /// explanation special technique
	(10_4=13) /// Benford procedure
	(8_2 9_4 10_6 11_5=14) (8_4 9_6 10_8 11_8=15) /// sensitive questions
	(8_6 9_8 10_10 11_11=16) (8_8 9_10 10_12 11_14=17) /// sensitive questions
	(12_3=18) (12_8=19) ///
	(13_2 14_5 15_5 16_3 17_3=20) /// Randomizing device test
	(18_2=21) (18_4=22)
gettoken grp grps : grps, match(paren)
while ("`grp'"!="") {
    gettoken org grp : grp, parse("=")
    gettoken grp des : grp, parse("=")
    qui gen firstcl`des' = .
		lab var firstcl`des' "Secs pageload to first click p`des' (`page`des'')"
	qui gen lastcl`des' = .
		lab var lastcl`des' "Secs pageload to last click p`des' (excl. submit) (`page`des'')"
    qui gen submit`des' = .
		lab var submit`des' "Secs pageload to submit p`des' (`page`des'')"
    qui gen clcount`des' = .
		lab var clcount`des' "Click count p`des' (excl. submit) (`page`des'')"
    foreach o of local org {
        assert (firstcl`des'>=.) if Q`o'_1<.
        qui replace firstcl`des' = Q`o'_1 if Q`o'_1<.
        assert (lastcl`des'>=.) if Q`o'_2<.
        qui replace lastcl`des' = Q`o'_2 if Q`o'_2<.
        assert (submit`des'>=.) if Q`o'_3<.
        qui replace submit`des' = Q`o'_3 if Q`o'_3<.
        assert (clcount`des'>=.) if Q`o'_4<.
        qui replace clcount`des' = Q`o'_4 if Q`o'_4<.
		drop Q`o'_1 Q`o'_2 Q`o'_3 Q`o'_4 
	}
    gettoken grp grps : grps, match(paren)
}
* Browser information
local i 0
foreach org in 1_2 18_5 {
	local ++i
	local dest : word `i' of 1 21
	encode Q`org'_1, gen(browser`dest') label(browser`dest')
		order browser`dest', after(Q`org'_1)
		drop Q`org'_1
		lab var browser`dest' "Browser name p`dest'"
	rename Q`org'_2 version`dest'
		lab var version`dest' "Browser version p`dest'"
	rename Q`org'_3 system`dest'
		lab var system`dest' "Operating system p`dest'"
	rename Q`org'_4 screen`dest'
		lab var screen`dest' "Screen resolution p`dest'"
	rename Q`org'_5 flash`dest'
		lab var flash`dest' "Adobe Flash version (-1 not installed) p`dest'"
	rename Q`org'_6 java`dest'
		lab var java`dest' "Java support  p`dest'"
	rename Q`org'_7 user`dest'
		lab var user`dest' "User agent string p`dest'"
	}

order browser1-user1 browser21-user21, before(firstcl1)
	
qui compress

exit

